@@ -1,23 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2007 by Joris Guisson and Ivan Vasic                    *
- *   joris.guisson@gmail.com                                               *
- *   ivasic@gmail.com                                                      *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007 Joris Guisson <joris.guisson@gmail.com>
+    SPDX-FileCopyrightText: 2007 Ivan Vasic <ivasic@gmail.com>
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "weekview.h"
 
@@ -25,7 +10,7 @@
 
 #include "schedule.h"
 #include "weekscene.h"
-#include <boost/bind.hpp>
+#include <boost/bind/bind.hpp>
 #include <util/log.h>
 
 using namespace bt;
@@ -77,7 +62,7 @@ void WeekView::setSchedule(Schedule *s)
     schedule = s;
 
     if (schedule)
-        s->apply(boost::bind(&WeekView::addScheduleItem, this, _1));
+        s->apply(boost::bind(&WeekView::addScheduleItem, this, boost::placeholders::_1));
 
     scene->setSchedule(s);
 }
@@ -93,7 +78,7 @@ void WeekView::clear()
     }
     item_map.clear();
     selection.clear();
-    schedule = 0;
+    schedule = nullptr;
 }
 
 void WeekView::removeSelectedItems()
